@@ -22,8 +22,6 @@
 import logging
 from typing import Optional
 
-from squeak.core import CSqueak
-
 from proto import squeak_admin_pb2
 from squeaknode.admin.profile_image_util import bytes_to_base64_string
 from squeaknode.admin.profile_image_util import load_default_profile_image
@@ -50,6 +48,7 @@ DEFAULT_PROFILE_IMAGE = load_default_profile_image()
 
 def squeak_entry_to_message(squeak_entry: SqueakEntry) -> squeak_admin_pb2.SqueakDisplayEntry:
     squeak_profile = squeak_entry.squeak_profile
+    secret_key = squeak_entry.secret_key.hex() if squeak_entry.secret_key else None
     is_reply = bool(squeak_entry.reply_to)
     reply_to = squeak_entry.reply_to.hex() if squeak_entry.reply_to else None
     is_author_known = False
@@ -59,7 +58,9 @@ def squeak_entry_to_message(squeak_entry: SqueakEntry) -> squeak_admin_pb2.Squea
         profile_msg = squeak_profile_to_message(squeak_profile)
     return squeak_admin_pb2.SqueakDisplayEntry(
         squeak_hash=squeak_entry.squeak_hash.hex(),
+        serialized_squeak_hex=squeak_entry.serialized_squeak.hex(),
         is_unlocked=squeak_entry.is_unlocked,
+        secret_key_hex=secret_key,  # type: ignore
         content_str=squeak_entry.content,  # type: ignore
         block_height=squeak_entry.block_height,
         block_hash=squeak_entry.block_hash.hex(),
@@ -132,13 +133,6 @@ def sent_payment_to_message(sent_payment: SentPayment) -> squeak_admin_pb2.SentP
     )
 
 
-def squeak_to_detail_message(squeak: CSqueak) -> squeak_admin_pb2.SqueakDetailEntry:
-    serialized_squeak = squeak.serialize()
-    return squeak_admin_pb2.SqueakDetailEntry(
-        serialized_squeak_hex=serialized_squeak.hex(),
-    )
-
-
 def sent_offer_to_message(sent_offer: SentOffer) -> squeak_admin_pb2.SentOffer:
     sent_offer_id = sent_offer.sent_offer_id or 0
     return squeak_admin_pb2.SentOffer(
@@ -214,8 +208,11 @@ def message_to_squeak_entry(msg: squeak_admin_pb2.SqueakDisplayEntry) -> SqueakE
     like_time_ms = msg.liked_time_ms if msg.liked_time_ms > 0 else None
     reply_to_hash = bytes.fromhex(msg.reply_to) if msg.reply_to else None
     content_str = msg.content_str if len(msg.content_str) > 0 else None
+    secret_key = bytes.fromhex(
+        msg.secret_key_hex) if msg.secret_key_hex else None
     return SqueakEntry(
         squeak_hash=bytes.fromhex(msg.squeak_hash),
+        serialized_squeak=bytes.fromhex(msg.serialized_squeak_hex),
         address=msg.author_address,
         block_height=msg.block_height,
         block_hash=bytes.fromhex(msg.block_hash),
@@ -223,6 +220,7 @@ def message_to_squeak_entry(msg: squeak_admin_pb2.SqueakDisplayEntry) -> SqueakE
         squeak_time=msg.squeak_time,
         reply_to=reply_to_hash,
         is_unlocked=msg.is_unlocked,
+        secret_key=secret_key,
         squeak_profile=None,  # TODO: message to squeak profile
         liked_time_ms=like_time_ms,
         content=content_str,
@@ -318,12 +316,6 @@ def optional_sent_payment_to_message(sent_payment: Optional[SentPayment]) -> Opt
     return sent_payment_to_message(sent_payment)
 
 
-def optional_squeak_to_detail_message(squeak: Optional[CSqueak]) -> Optional[squeak_admin_pb2.SqueakDetailEntry]:
-    if squeak is None:
-        return None
-    return squeak_to_detail_message(squeak)
-
-
 def optional_connected_peer_to_message(connected_peer: Optional[ConnectedPeer]) -> Optional[squeak_admin_pb2.ConnectedPeer]:
     if connected_peer is None:
         return None
